"""
@Version: 1.0.0
@Author: qi.you
@File: rpa_getcmd.py
@Time: 2020/3/6 10:42
@Describe: 获取RPA传入的参数并解析，包括程序名和json参数
"""

import json
import sys


def getcmd():
    print('获取RPA传入的参数并解析，包括程序名和json参数')
    try:
        jsonpath = ''
        exename = ''
        load_dict = {}
        if len(sys.argv) > 2:
            exename = sys.argv[1]
            jsonpath = sys.argv[2].replace('\\', '/')
        if jsonpath:
            with open(jsonpath, 'r') as load_f:
                load_dict = json.load(load_f)
        return exename, eval(load_dict)
    except Exception as e:
        return e, e




if __name__=="__main__":
    exename, load_dict=getcmd()
    print(exename, load_dict)


"""
@Version: 1.0.0
@Author: qi.you
@File: setup.py
@Time: 2020/3/6 11:27
@Describe: 
"""
import setuptools

setuptools.setup(
    name="rpa_getcmd",                                     # 包的分发名称，使用字母、数字、_、-
    version="1.0.1",                                        # 版本号, 版本号规范：https://www.python.org/dev/peps/pep-0440/
    author="qi.you",                                       # 作者名字
    author_email="youqi6588@126.com",                      # 作者邮箱
    description="取RPA传入的参数并解析，包括程序名和json参数",                            # 包的简介描述
    #long_description=long_description,                      # 包的详细介绍(一般通过加载README.md)
    #long_description_content_type="text/markdown",          # 和上条命令配合使用，声明加载的是markdown文件
    url="https://github.com/youqi6588/RPA",                              # 项目开源地址
    packages=setuptools.find_packages(),                    # 如果项目由多个文件组成，我们可以使用find_packages()自动发现所有包和子包，而不是手动列出每个包，在这种情况下，包列表将是example_pkg
    classifiers=[                                           # 关于包的其他元数据(metadata)
        "Programming Language :: Python :: 3",              # 该软件包仅与Python3兼容
        "License :: OSI Approved :: MIT License",           # 根据MIT许可证开源
        "Operating System :: OS Independent",               # 与操作系统无关
    ],
)

